@@ -1,8 +1,9 @@
 var searchData=
 [
+  ['background',['BACKGROUND',['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_template_runtime_1_1_focus_state.html#a0705240859115be4fef17ddaf55d2a81',1,'com::amazon::aace::alexa::TemplateRuntime::FocusState']]],
   ['bass',['BASS',['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_equalizer_controller_1_1_equalizer_band.html#ab912928dd1ef3bee8dbbd6949b9f4f21',1,'com::amazon::aace::alexa::EqualizerController::EqualizerBand']]],
   ['bluetooth',['BLUETOOTH',['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_local_media_source_1_1_source.html#a6727f90887ea62c4e2cc8df0fb3257b6',1,'com::amazon::aace::alexa::LocalMediaSource::Source']]],
-  ['buffer_5funderrun',['BUFFER_UNDERRUN',['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_audio_player_1_1_player_activity.html#a947333e7e18f62ecb6cf1387c34a12f3',1,'com::amazon::aace::alexa::AudioPlayer::PlayerActivity']]],
+  ['buffer_5funderrun',['BUFFER_UNDERRUN',['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_audio_player_1_1_player_activity.html#a947333e7e18f62ecb6cf1387c34a12f3',1,'com.amazon.aace.alexa.AudioPlayer.PlayerActivity.BUFFER_UNDERRUN()'],['../enumcom_1_1amazon_1_1aace_1_1alexa_1_1_template_runtime_1_1_player_activity.html#a0034f77e833be6173541a1b5993b7321',1,'com.amazon.aace.alexa.TemplateRuntime.PlayerActivity.BUFFER_UNDERRUN()']]],
   ['buffering',['BUFFERING',['../enumcom_1_1amazon_1_1aace_1_1audio_1_1_audio_output_1_1_media_state.html#a9f93dc6ebc20250f7e88ba87c8d9d649',1,'com::amazon::aace::audio::AudioOutput::MediaState']]],
   ['busy',['BUSY',['../enumcom_1_1amazon_1_1aace_1_1phonecontrol_1_1_phone_call_controller_1_1_call_error.html#ad5423ebda1428be66d0d2f5c44a63b6b',1,'com::amazon::aace::phonecontrol::PhoneCallController::CallError']]],
   ['buttonpressed',['buttonPressed',['../classcom_1_1amazon_1_1aace_1_1alexa_1_1_playback_controller.html#a505dae16002e9ee0a492c9097cca57b9',1,'com::amazon::aace::alexa::PlaybackController']]]
