@@ -5,5 +5,6 @@ var searchData=
   ['platforminterface',['PlatformInterface',['../classaace_1_1core_1_1_platform_interface.html',1,'aace::core']]],
   ['playbackcontroller',['PlaybackController',['../classaace_1_1alexa_1_1_playback_controller.html',1,'aace::alexa']]],
   ['playbackcontrollerengineinterface',['PlaybackControllerEngineInterface',['../classaace_1_1alexa_1_1_playback_controller_engine_interface.html',1,'aace::alexa']]],
-  ['playbackstate',['PlaybackState',['../classaace_1_1alexa_1_1_external_media_adapter_1_1_playback_state.html',1,'aace::alexa::ExternalMediaAdapter::PlaybackState'],['../classaace_1_1alexa_1_1_local_media_source_1_1_playback_state.html',1,'aace::alexa::LocalMediaSource::PlaybackState']]]
+  ['playbackstate',['PlaybackState',['../classaace_1_1alexa_1_1_external_media_adapter_1_1_playback_state.html',1,'aace::alexa::ExternalMediaAdapter::PlaybackState'],['../classaace_1_1alexa_1_1_local_media_source_1_1_playback_state.html',1,'aace::alexa::LocalMediaSource::PlaybackState']]],
+  ['propertymanager',['PropertyManager',['../classaace_1_1property_manager_1_1_property_manager.html',1,'aace::propertyManager']]]
 ];
