@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * Copyright 2018-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License").
  * You may not use this file except in compliance with the License.
@@ -32,8 +32,8 @@ public:
     MOCK_METHOD0(getStream, std::shared_ptr<std::istream>());
 };
 
-} // aace::test::core
-} // aace::test
-} // aace
+}  // namespace core
+}  // namespace test
+}  // namespace aace
 
-#endif // AACE_ENGINE_TEST_CORE_MOCK_ENGINE_CONFIGURATION_H
+#endif  // AACE_ENGINE_TEST_CORE_MOCK_ENGINE_CONFIGURATION_H
