@@ -1,5 +1,5 @@
 /*
- * Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * Copyright 2019-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License").
  * You may not use this file except in compliance with the License.
@@ -23,17 +23,18 @@ namespace aace {
 namespace jni {
 namespace native {
 
-    JavaField::JavaField( const std::string& name, const std::string& signature, jfieldID fieldID ) : m_name( name ), m_signature( signature ), m_fieldID( fieldID ) {
-    }
+JavaField::JavaField(const std::string& name, const std::string& signature, jfieldID fieldID) :
+        m_name(name), m_signature(signature), m_fieldID(fieldID) {
+}
 
-    std::shared_ptr<JavaField> JavaField::create( const char* name, const char* signature, jfieldID fieldID ) {
-        return std::shared_ptr<JavaField>( new JavaField( name, signature, fieldID ) );
-    }
+std::shared_ptr<JavaField> JavaField::create(const char* name, const char* signature, jfieldID fieldID) {
+    return std::shared_ptr<JavaField>(new JavaField(name, signature, fieldID));
+}
 
-    jfieldID JavaField::getFieldID() {
-        return m_fieldID;
-    }
+jfieldID JavaField::getFieldID() {
+    return m_fieldID;
+}
 
-} // aace::jni::native
-} // aace::jni
-} // aace
+}  // namespace native
+}  // namespace jni
+}  // namespace aace
