@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License").
  * You may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@
 package com.amazon.maccandroid.model;
 
 public class PlayBackStateFields {
-
     public enum State {
         IDLE,
         PLAYING,
@@ -25,24 +24,27 @@ public class PlayBackStateFields {
         FINISHED,
         FAST_FORWARDING,
         REWINDING,
-        BUFFER_UNDERRUN,;
+        BUFFER_UNDERRUN,
+        ;
     }
 
     public enum shuffle {
         SHUFFLED,
-        NOT_SHUFFLED,;
+        NOT_SHUFFLED,
+        ;
     }
 
     public enum repeat {
         REPEATED,
         ONE_REPEATED,
-        NOT_REPEATED,;
+        NOT_REPEATED,
+        ;
     }
 
     public enum favorite {
         NOT_RATED,
         FAVORITED,
-        UNFAVORITED,;
+        UNFAVORITED,
+        ;
     }
-
 }
